aboutsummaryrefslogtreecommitdiff
path: root/engines/tinsel/background.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/tinsel/background.cpp')
-rw-r--r--engines/tinsel/background.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/tinsel/background.cpp b/engines/tinsel/background.cpp
index f895ecd2da..50b7ff90f5 100644
--- a/engines/tinsel/background.cpp
+++ b/engines/tinsel/background.cpp
@@ -51,8 +51,8 @@ void InitBackground(const BACKGND *pBgnd) {
// set current background
pCurBgnd = pBgnd;
- // init background sky colour
- SetBgndColour(pBgnd->rgbSkyColour);
+ // init background sky color
+ SetBgndColor(pBgnd->rgbSkyColor);
// start of playfield array
pPlayfield = pBgnd->fieldArray;